CondensedHtmlRenderer class

Translates a parsed AST to HTML.

Unlike HtmlRenderer, it doesn't generate linefeeds among ul, li, and ul tags. Thus, the caller can apply white-space: pre-wrap and similar styles safely.

Implemented types
Implementers

Constructors

CondensedHtmlRenderer({bool enableTagfilter = false})

Properties

buffer ↔ StringBuffer
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uniqueIds ↔ Set<String>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(List<Node> nodes) → String
toString() → String
A string representation of this object.
inherited
uniquifyId(String id) → String
Uniquifies an id generated from text.
visitElementAfter(Element element) → void
Called when an Element has been reached, after its children have been visited.
override
visitElementBefore(Element element) → bool
Called when an Element has been reached, before its children have been visited.
override
visitText(Text text) → void
Called when a Text node has been reached.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited