Document class

Maintains the context needed to parse a Markdown document.

Constructors

Document({Iterable<BlockSyntax>? blockSyntaxes, Iterable<InlineSyntax>? inlineSyntaxes, ExtensionSet? extensionSet, Resolver? linkResolver, Resolver? imageLinkResolver, bool encodeHtml = true, bool withDefaultBlockSyntaxes = true, bool withDefaultInlineSyntaxes = true, bool checkable = false, bool preserveSpace = false, dynamic options, BlockParserBuilder blockParserBuilder = BlockParser.new, InlineParserBuilder inlineParserBuilder = InlineParser.new})
Document.be(BlockParserBuilder _blockParserBuilder, InlineParserBuilder _inlineParserBuilder, {Resolver? linkResolver, Resolver? imageLinkResolver, bool encodeHtml = true, bool withDefaultBlockSyntaxes = true, bool withDefaultInlineSyntaxes = true, bool hasCustomInlineSyntaxes = false, bool checkable = false, bool preserveSpace = false, dynamic options})
Constructs a fully customized Document. Usually used with BlockParser.be and InlineParser.be.

Properties

blockSyntaxes → Iterable<BlockSyntax>
no setter
checkable → bool
Whether the checkbox in the check list is checkable.
final
encodeHtml → bool
final
footnoteLabels → List<String>
Footnote labels by appearing order.
final
footnoteReferences → Map<String, int>
Footnote ref count, keys are case-sensitive and added by define syntax.
final
hasCustomInlineSyntaxes → bool
final
hashCode → int
The hash code for this object.
no setterinherited
imageLinkResolver → Resolver?
final
inlineSyntaxes → Iterable<InlineSyntax>
no setter
linkReferences → Map<String, LinkReference>
final
linkResolver → Resolver?
final
options → dynamic
An application specific instance.
final
preserveSpace → bool
Whether to preserve the white spaces.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
withDefaultBlockSyntaxes → bool
Whether to use default block syntaxes.
final
withDefaultInlineSyntaxes → bool
Whether to use default inline syntaxes.
final

Methods

getBlockParser(List<Line> lines, {int offset = 0}) → BlockParser
getInlineParser(String text) → InlineParser
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String text) → List<Node>
Parses the given text to a series of AST nodes.
parseInline(String text) → List<Node>
Parses the given inline Markdown text to a series of AST nodes.
parseLineList(List<Line> lines, {int offset = 0}) → List<Node>
Parses the given lines of Line to a series of AST nodes.
parseLines(List<String> lines, {int offset = 0}) → List<Node>
Parses the given lines of Markdown to a series of AST nodes.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited