InlineParser class

Maintains the internal state needed to parse inline span elements in Markdown.

Inheritance

Constructors

InlineParser(String source, Document document)
InlineParser.be(String source, Document document, List<InlineSyntax> syntaxes)

Properties

document → Document
The Markdown document this parser is parsing.
final
encodeHtml → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
isDone → bool
no setterinherited
options → dynamic
The options passed to document.
no setter
pos ↔ int
The current read position.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
The string of Markdown being parsed.
finalinherited
start ↔ int
Starting position of the last unconsumed text.
getter/setter pair
syntaxes → List<InlineSyntax>
final

Methods

addNode(Node node) → void
Add node to the current tree.
advanceBy(int length) → void
inherited
charAt(int index) → int
inherited
consume(int length) → void
existsDilimiter(bool test(Delimiter delimiter)) → bool
Tests if a delimiter exists.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse() → List<Node>
pushDelimiter(Delimiter delimiter) → void
Push delimiter onto the stack of Delimiters.
toString() → String
A string representation of this object.
inherited
writeText() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited