LinkContext class

A helper class holds params of link context. Footnote creation needs other info in _tryCreateReferenceLink.

Constructors

LinkContext(InlineParser parser, SimpleDelimiter opener, List<Node> getChildren())
const

Properties

getChildren → List<Node> Function()
final
hashCode → int
The hash code for this object.
no setterinherited
opener → SimpleDelimiter
final
parser → InlineParser
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited