LinkSyntax class

Matches links like [blah][label] and [blah](url).

Inheritance
Implementers

Constructors

LinkSyntax({Resolver? linkResolver, LinkMapper? linkMapper, String pattern = r'\[', int startCharacter = $lbracket})

Properties

allowIntraWord → bool
Whether to allow intra-word delimiter runs. CommonMark emphasis and strong emphasis does not allow this, but GitHub-Flavored Markdown allows it on strikethrough.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
linkMapper → LinkMapper?
final
linkResolver → Resolver
final
pattern → RegExp
finalinherited
removeOpener → bool
Whether to remove the opener's delimiter text once close is called.
no setterinherited
requiresDelimiterRun → bool
Whether this is parsed according to the same nesting rules as emphasis delimiters.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<DelimiterTag>?
finalinherited

Methods

close(InlineParser parser, covariant SimpleDelimiter opener, Delimiter? closer, {String? tag, required List<Node> getChildren()}) → Iterable<Node>?
Attempts to close this tag at the current position.
override
createNode(InlineParser parser, String destination, String? title, {required List<Node> getChildren()}) → Node
Create the node represented by a Markdown link.
matches(InlineParser parser, int startMatchPos) → Match?
Test if this syntax matches the current source.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMatch(InlineParser parser, Match match) → bool
Processes match, adding nodes to parser and possibly advancing parser.
inherited
toString() → String
A string representation of this object.
inherited
tryMatch(InlineParser parser, [int? startMatchPos]) → bool
Tries to match at the parser's current position.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited