SimpleDelimiter class

A simple delimiter implements the Delimiter interface with basic fields, and does not have the concept of "left-flanking" or "right-flanking".

Implemented types

Constructors

SimpleDelimiter({required Text node, required int char, required int length, required bool canOpen, required bool canClose, required DelimiterSyntax syntax, required int endPos})

Properties

canClose → bool
Whether this delimiter can close emphasis or strong emphasis.
final
canOpen → bool
Whether this delimiter can open emphasis or strong emphasis.
final
char → int
The type of delimiter.
final
endPos → int
final
hashCode → int
The hash code for this object.
no setterinherited
isActive ↔ bool
Whether the delimiter is active.
getter/setter pairoverride
length → int
The number of delimiters.
final
node ↔ Text
The Text node representing the plain text representing this delimiter.
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syntax → DelimiterSyntax
The syntax which uses this delimiter to parse a tag.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited