SimpleInlineParser class

A simple parser

Inheritance
Implementers

Constructors

SimpleInlineParser(String source)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDone → bool
no setter
pos ↔ int
The current read position.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
The string of Markdown being parsed.
finalinherited

Methods

advanceBy(int length) → void
charAt(int index) → int
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited