SimpleParser class

A simple parser for using with DelimiterRun.

Implementers

Constructors

SimpleParser(String source)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
The string of Markdown being parsed.
final

Methods

charAt(int index) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited