TableSyntax class

Parses tables.

Inheritance

Constructors

TableSyntax()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pattern → RegExp
Gets the regex used to identify the beginning of this block, if any.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canEndBlock(BlockParser parser) → bool
override
canParse(BlockParser parser) → bool
override
escapeForward(BlockParser parser, String line, int index) → int
Escapes the character at index, if necessary, by returning the next index to continue the splitting of a row.
interruptedBy(BlockParser parser) → BlockSyntax?
Returns the block which interrupts current syntax parsing if there is one, otherwise returns null.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BlockParser parser) → Node?
Parses a table into its three parts:
override
parseChildLines(BlockParser parser) → List<Line?>
inherited
processCellContent(BlockParser parser, String cellContent) → String
Processes the given cell content (cellContent). It is a callback for subclasses to pre-process the cell's content
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited