TextRenderer class

Translates a parsed AST to plain text. It is used to generate a text version of markdown.

For better, you can use just EmptyBlockSyntax and ParagraphSyntax.

Inheritance

Constructors

TextRenderer()

Properties

buffer ↔ StringBuffer
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uniqueIds ↔ Set<String>
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(List<Node> nodes) → String
inherited
toString() → String
A string representation of this object.
inherited
uniquifyId(String id) → String
Uniquifies an id generated from text.
inherited
visitElementAfter(Element element) → void
Called when an Element has been reached, after its children have been visited.
inherited
visitElementBefore(Element element) → bool
Called when an Element has been reached, before its children have been visited.
inherited
visitText(Text text) → void
Called when a Text node has been reached.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited