TextSyntax class

Matches stuff that should just be passed through as straight text.

Inheritance
Implementers

Constructors

TextSyntax(String pattern, {String sub = '', int? startCharacter, bool caseSensitive = true})
Create a new TextSyntax which matches text on pattern.

Properties

hashCode → int
The hash code for this object.
no setterinherited
pattern → RegExp
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
substitute → String
final

Methods

matches(InlineParser parser, int startMatchPos) → Match?
Test if this syntax matches the current source.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMatch(InlineParser parser, Match match) → bool
Adds a Text node to parser and returns true if there is a substitute, as long as the preceding character (if any) is not a /.
override
toString() → String
A string representation of this object.
inherited
tryMatch(InlineParser parser, [int? startMatchPos]) → bool
Tries to match at the parser's current position.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited