UnparsedContent class

Inline content that has not been parsed into inline nodes (strong, links, etc).

These placeholder nodes should only remain in place while the block nodes of a document are still being parsed, in order to gather all reference link definitions.

Implemented types

Constructors

UnparsedContent(String textContent)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textContent → String
final

Methods

accept(NodeVisitor visitor) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited