maxNestingLevel constant

int const maxNestingLevel

The maximal levels of nested blocks, such as blockquotes and lists. The lines nested deeper are parsed as a paragraph, so a deeply nested input (such as 10,000 >) won't overflow the stack.

Implementation

static const maxNestingLevel = 32;