ListItem class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lines
→ List<
Line> -
final
- offset → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskListItemOffset → int?
-
The line of the task list item's marker (
[ ]or[x]), if any. It differs from offset if the item starts with an empty line. Default: offset.final - taskListItemState → TaskListItemState?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited